@@ -48,7 +48,7 @@ from cloudmesh.common.util import path_expand, readfile
 
 def NotImplementedInWindows():
     if sys.platform == "win32":
-        Console.error("The method {f.__name__} is not implemented in Windows,"
+        Console.error(f"The method {__name__} is not implemented in Windows,"
                       " please implement, and/or submit an issue.")
         sys.exit()
 
@@ -407,17 +407,31 @@ class Shell(object):
         else:
             os.system("python -m webbrowser -t {file}".format(**data))
 
-    # @NotImplementedInWindows
+
+    @staticmethod
+    def terminal_title(name):
+        return f'echo -n -e \"\033]0;{name}\007\"'
+
     @classmethod
-    def terminal(cls, command='pwd'):
-        NotImplementedInWindows()
+    def terminal(cls, command='pwd', title=None):
+        # title nameing not implemented
+        print (platform)
         if platform == 'darwin':
+            label = Shell.terminal_title(title)
+
             os.system(
-                "osascript -e 'tell application \"Terminal\" to do script \"{command}\"'".format(
-                    **locals())
+                f"osascript -e 'tell application \"Terminal\" to do script \"{command}\"'"
             )
-        elif platform == "linus":  # for ubuntu running gnome
-            os.system('gnome-terminal --command="{command}"'.format(**locals()))
+        elif platform == "linux":  # for ubuntu running gnome
+            os.system(f'gnome-terminal -e \'bash -c "{command}; bash"\'')
+        elif platform == "win32":
+            if Path.is_dir(Path(r"C:\Program Files\Git\bin")):
+                subprocess.check_call([r"C:\Program Files\Git\bin\sh.exe",
+                                       "-c", f"{command}"])
+            else:
+                Console.error("Git bash is not found, please make sure it "
+                              "is installed.")
+                raise NotImplementedError
         else:
             raise NotImplementedError
 
